==> openGion6.4.0.3_dev.zip: uap/webapps/gf/src/org/opengion/fukurou/mail/MailReceiver.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.fukurou.mail;

import org.opengion.fukurou.util.HybsEntry ;
import org.opengion.fukurou.util.Argument ;
// import org.opengion.fukurou.util.LogWriter;						// 6.3.8.0 (2015/09/11) 削除
import static org.opengion.fukurou.util.HybsConst.CR;				// 6.1.0.0 (2014/12/26) refactoring

import java.util.Map;
import java.util.LinkedHashMap;

import java.util.logging.Logger;
import java.util.logging.Level;
import javax.mail.MessagingException ;

/**
 * MailReceiver は、POP3/IMAPプロトコルによるメール受信プログラムです。
 *
 * 引数には、host,user,passwd などが指定できます。
 * メールは、メッセージID名をファイル名として、セーブします。
 * 添付ファイルは、元のファイル名で、指定のディレクトリに出力される為、複数のメールを
 * 同時に抜く場合は、uniq 属性を付与してください。その場合は、メッセージID＋連番＋元のファイル名
 * で、ファイルをセーブします。添付ファイルには、同名のファイルを複数添付することが
 * できるため、保存時には、添付ファイルの番号を連番としてファイル名に、付与します。
 *
 * 引数のプロパテイのキー部は、大文字・小文字が厳格に適用されますので、正確に記述願います。
 *
 * Usage: java org.opengion.fukurou.fukurou.mail.MailReceiver
 *        -host=メールサーバー(必須)
 *        -user=メールを取得するログインユーザー(必須)
 *        -passwd=メールを取得するログインパスワード(必須)
 *        -protocol=受信サーバーのプロトコル[imap/pop3]を指定(初期値:{@og.value #PROTOCOL})
 *        -port=受信サーバーのポートを指定(初期値:{@og.value #PORT})
 *        -useSSL=SSL接続するかどうか[true:する/false:しない]を指定(初期値:false:しない)
 *        -mailSaveDir=受信メールをセーブするディレクトリ。指定がない場合は、標準出力へ出力する。
 *        -fileSaveDir=添付ファイルをセーブするディレクトリ。指定がない場合は抜き出さない。
 *        -useMsgId=添付ファイルをセーブするディレクトリに、MesssageIdフォルダを個別に割り当てるかどうか(初期値:false)
 *        -maxRowCount=受信メールの最大取り込み件数(初期値:{@og.value #MAX_ROW_COUNT})(0:[無制限])
 *        -match_Subject=受信メールのSubjectを選択する条件
 *        -match_Body=受信メールのBodyを選択する条件
 *        -match_From=受信メールのFromを選択する条件
 *        -match_XXXX=受信メールのヘッダー部のキーXXXXを選択する条件
 *        -delete=検索後、メールをサーバーから削除するかどうかを、true/falseで指定(初期値:false)
 *        -help=使用方法を出力して、終了します。
 *
 * ※ 6.3.8.0 (2015/09/11)
 *    useSSL属性は、protocolに、pop3s/imaps を指定した場合、
 *    自動的に、ture に設定するようにしています。
 *
 * @version  0.9.0  2000/11/13
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class MailReceiver {
	// 6.3.9.1 (2015/11/27) The Logger variable declaration does not contain the static and final modifiers(PMD)
//	private static Logger logger = Logger.getLogger( "org.opengion.fukurou.fukurou.mail.MailReceiver" );			// 4.3.3.5 (2008/11/08)
	private static final Logger logger = Logger.getLogger( "org.opengion.fukurou.fukurou.mail.MailReceiver" );		// 4.3.3.5 (2008/11/08)

	/** 受信メールの最大取り込み件数を指定します 「={@value}」  */
	public static final int MAX_ROW_COUNT = 100 ;

	/** 検索後、メールをサーバーから削除するかどうかを、true/falseで指定します 「={@value}」  */
	public static final boolean DELETE_MESSAGE = false ;

	/** メールサーバーのデフォルトプロトコル 「={@value}」  */
	public static final String PROTOCOL = "pop3" ;

	/** メールサーバーのデフォルトポート番号 「={@value}」  */
	public static final int PORT = -1 ;

	private Argument argment ;

	private static final Map<String,String> mustProparty   ;
	private static final Map<String,String> usableProparty ;

	static {
		mustProparty = new LinkedHashMap<>();
		mustProparty.put( "host"	, "メールサーバー(必須)" );
		mustProparty.put( "user"	, "メールを取得するログインユーザー(必須)" );
		mustProparty.put( "passwd"	, "メールを取得するログインパスワード(必須)" );

		usableProparty = new LinkedHashMap<>();
		usableProparty.put( "protocol"		, "受信サーバーのプロトコル(imap,pop3)を指定(初期値:pop3)" );
		usableProparty.put( "port"			, "受信サーバーのポートを指定(初期値:-1)" );
		usableProparty.put( "useSSL"		, "SSL接続するかどうかを指定(初期値:false:しない)" );		// 6.3.8.0 (2015/09/11)
		usableProparty.put( "mailSaveDir"	, "受信メールをセーブするディレクトリ。" +
											CR + "指定がない場合は、標準出力へ出力する。" );
		usableProparty.put( "fileSaveDir"	, "添付ファイルをセーブするディレクトリ。" +
											CR + "指定がない場合は抜き出さない。" );
		usableProparty.put( "useMsgId"		, "添付ファイルをセーブするディレクトリに、" +
											CR + "MesssageIdフォルダを個別に割り当てるかどうか。" );
		usableProparty.put( "maxRowCount"	, "受信メールの最大取り込み件数(初期値:100)(0:[無制限])" );
		usableProparty.put( "match_Subject"	, "受信メールのSubjectを選択する条件" );
		usableProparty.put( "match_Body"	, "受信メールのBodyを選択する条件" );
		usableProparty.put( "match_From"	, "受信メールのFromを選択する条件" );
		usableProparty.put( "match_"		, "受信メールのヘッダー部のキーXXXXを選択する条件" );
		usableProparty.put( "delete"		, "検索後、メールをサーバーから削除するかどうかを、" +
											CR + "true/falseで指定(初期値:false)" );
		usableProparty.put( "help"			, "使用方法を出力して、終了します。" );
	}

	/**
	 * レシーバーを開始します。
	 *
	 * @og.rev 4.3.3.5 (2008/11/08) Argument オブジェクトへの引数を util → mail に訂正します。
	 * @og.rev 6.3.8.0 (2015/09/11) SSL接続するかどうかを指定するパラメータを追加します。
	 *
	 * @param   args 引数配列(可変長引数)
	 * @throws MessagingException なんらかのエラーが発生した場合。
	 */
	public void start( final String... args ) throws MessagingException {

		// パラメータの解析、取得
		logger.fine( "パラメータの解析、取得" );
		argment = new Argument( "org.opengion.fukurou.fukurou.mail.MailReceiver" );		// 4.3.3.5 (2008/11/08)
		argment.setMustProparty( mustProparty );
		argment.setUsableProparty( usableProparty );

		argment.setArgument( args );

		// help パラメータが true に指定された場合の処理。
		if( argment.getProparty( "help",false ) ) {
			System.out.println( argment.toString() );
			return;
		}

		// 処理に必要な各種パラメータを取得しておきます。
		logger.fine( "処理に必要な各種パラメータを取得します。" );
		final MailRX recive = new MailRX();

		recive.setHost(			argment.getProparty( "host" ) ) ;
		recive.setUser(			argment.getProparty( "user" ) ) ;
		recive.setPasswd(		argment.getProparty( "passwd" ) ) ;
		recive.setProtocol(		argment.getProparty( "protocol"	,PROTOCOL ) ) ;
		recive.setPort(			argment.getProparty( "port"		,PORT ) ) ;
		recive.useSSL(			argment.getProparty( "useSSL"	,false ) ) ;			// 6.3.8.0 (2015/09/11)
		recive.setDelete(		argment.getProparty( "delete"	,DELETE_MESSAGE ) ) ;
		recive.setMaxRowCount(	argment.getProparty( "maxRowCount",MAX_ROW_COUNT ) ) ;

		// 指定の条件にマッチしたメッセージのみ抜き出す為の、SearchTerm オブジェクトの作成
		logger.fine( "指定の条件にマッチしたメッセージのみ抜き出す条件を設定します。" );
		final HybsEntry[] matchs = argment.getEntrys( "match_" );
		for( int i=0; i<matchs.length; i++ ) {
			recive.addMatchTerm( matchs[i] ) ;
		}

		// リスナーを設定して、受信メールを一件ずつ処理します。
		logger.fine( "リスナーを設定して、受信メールを一件ずつ処理します。" );
		final String mailSaveDir = argment.getProparty( "mailSaveDir" );
		final String fileSaveDir = argment.getProparty( "fileSaveDir" );
		final boolean useMsgId   = argment.getProparty( "useMsgId",false );

		final MailReceiveListener listener = new ReceiveListener( mailSaveDir,fileSaveDir,useMsgId ) ;
		recive.setMailReceiveListener( listener );

		recive.start();
	}

	/**
	 * メール受信プログラムで使用する MailReceiveListener の実装内部クラスです。
	 *
	 * @version  0.9.0  2000/11/13
	 * @author   Kazuhiko Hasegawa
	 * @since    JDK5.0,
	 */
	private static class ReceiveListener implements MailReceiveListener {
		private final String  mailSaveDir ;
		private final String  fileSaveDir ;
		private final boolean useMsgId ;
		private int   counter ;

		/**
		 * コンストラクター
		 *
		 * @param	mailSaveDir	メールをセーブする場合の保存フォルダ名
		 * @param	fileSaveDir	メールの添付ファイルをセーブする場合の保存フォルダ名
		 * @param	useMsgId	添付ファイルをセーブする場合に、メッセージIDを使用するかどうか
		 */
		public ReceiveListener( final String mailSaveDir,final String fileSaveDir,final boolean useMsgId ) {
			this.mailSaveDir = mailSaveDir;
			this.fileSaveDir = fileSaveDir;
			this.useMsgId    = useMsgId;
		}

		/**
		 * 受信処理を行います。
		 *
		 * @param   message MailMessageオブジェクト
		 * @return	結果(true:正常/false:異常)
		 */
		public boolean receive( final MailMessage message ) {
			final String msg = "[" + counter++ + "]" + message.getMessageID() + " 受信中" ;
			System.out.println( msg );

			if( mailSaveDir != null ) {
				message.saveMessage( mailSaveDir );
			}
			else {
				System.out.println( message.getSubject() );
				System.out.println( message.getContent() );
			}

			if( fileSaveDir != null ) {
				message.saveAttachFiles( fileSaveDir,useMsgId );
			}
			return true ;
		}
	}

	/**
	 * main メソッドです。
	 *
	 * @param	args	コマンド引数配列
	 */
	public static void main ( final String[] args ) {
		final MailReceiver receiver = new MailReceiver();
		try {
			logger.info( "メール受信処理を開始します  ---------------------------------------------" );
			receiver.start( args );
			logger.info( "正常に終了しました。" );
		}
		catch( Throwable th ) {
			final String errMsg = "メール受信中に例外が発生しました。 "
							+ CR + receiver.argment
							+ CR + th.getMessage() ;
//			LogWriter.log( errMsg );					// 6.3.8.0 (2015/09/11) 削除します。
			logger.log( Level.SEVERE,errMsg, th );
//			throw new RuntimeException( errMsg,th );	// 6.3.8.0 (2015/09/11) 削除します。
		}
	}
}

==> openGion6.4.2.0_dev.zip: uap/webapps/gf/src/org/opengion/fukurou/mail/MailReceiver.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.fukurou.mail;

import org.opengion.fukurou.util.HybsEntry ;
import org.opengion.fukurou.util.Argument ;
// import org.opengion.fukurou.system.LogWriter;						// 6.3.8.0 (2015/09/11) 削除
import static org.opengion.fukurou.system.HybsConst.CR;				// 6.1.0.0 (2014/12/26) refactoring

import java.util.Map;
import java.util.LinkedHashMap;

import java.util.logging.Logger;
import java.util.logging.Level;
import javax.mail.MessagingException ;

/**
 * MailReceiver は、POP3/IMAPプロトコルによるメール受信プログラムです。
 *
 * 引数には、host,user,passwd などが指定できます。
 * メールは、メッセージID名をファイル名として、セーブします。
 * 添付ファイルは、元のファイル名で、指定のディレクトリに出力される為、複数のメールを
 * 同時に抜く場合は、uniq 属性を付与してください。その場合は、メッセージID＋連番＋元のファイル名
 * で、ファイルをセーブします。添付ファイルには、同名のファイルを複数添付することが
 * できるため、保存時には、添付ファイルの番号を連番としてファイル名に、付与します。
 *
 * 引数のプロパテイのキー部は、大文字・小文字が厳格に適用されますので、正確に記述願います。
 *
 * Usage: java org.opengion.fukurou.fukurou.mail.MailReceiver
 *        -host=メールサーバー(必須)
 *        -user=メールを取得するログインユーザー(必須)
 *        -passwd=メールを取得するログインパスワード(必須)
 *        -protocol=受信サーバーのプロトコル[imap/pop3]を指定(初期値:{@og.value #PROTOCOL})
 *        -port=受信サーバーのポートを指定(初期値:{@og.value #PORT})
 *        -useSSL=SSL接続するかどうか[true:する/false:しない]を指定(初期値:false:しない)
 *        -mailSaveDir=受信メールをセーブするディレクトリ。指定がない場合は、標準出力へ出力する。
 *        -fileSaveDir=添付ファイルをセーブするディレクトリ。指定がない場合は抜き出さない。
 *        -useMsgId=添付ファイルをセーブするディレクトリに、MesssageIdフォルダを個別に割り当てるかどうか(初期値:false)
 *        -maxRowCount=受信メールの最大取り込み件数(初期値:{@og.value #MAX_ROW_COUNT})(0:[無制限])
 *        -match_Subject=受信メールのSubjectを選択する条件
 *        -match_Body=受信メールのBodyを選択する条件
 *        -match_From=受信メールのFromを選択する条件
 *        -match_XXXX=受信メールのヘッダー部のキーXXXXを選択する条件
 *        -delete=検索後、メールをサーバーから削除するかどうかを、true/falseで指定(初期値:false)
 *        -help=使用方法を出力して、終了します。
 *
 * ※ 6.3.8.0 (2015/09/11)
 *    useSSL属性は、protocolに、pop3s/imaps を指定した場合、
 *    自動的に、ture に設定するようにしています。
 *
 * @version  0.9.0  2000/11/13
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class MailReceiver {
	// 6.3.9.1 (2015/11/27) The Logger variable declaration does not contain the static and final modifiers(PMD)
//	private static Logger logger = Logger.getLogger( "org.opengion.fukurou.fukurou.mail.MailReceiver" );			// 4.3.3.5 (2008/11/08)
	private static final Logger LOGGER = Logger.getLogger( "org.opengion.fukurou.fukurou.mail.MailReceiver" );		// 6.4.1.1 (2016/01/16) logger → LOGGER refactoring

	/** 受信メールの最大取り込み件数を指定します 「={@value}」  */
	public static final int MAX_ROW_COUNT = 100 ;

	/** 検索後、メールをサーバーから削除するかどうかを、true/falseで指定します 「={@value}」  */
	public static final boolean DELETE_MESSAGE = false ;

	/** メールサーバーのデフォルトプロトコル 「={@value}」  */
	public static final String PROTOCOL = "pop3" ;

	/** メールサーバーのデフォルトポート番号 「={@value}」  */
	public static final int PORT = -1 ;

	private Argument argment ;

	private static final Map<String,String> MUST_PROPARTY   ;		// 6.4.1.1 (2016/01/16) mustProparty   → MUST_PROPARTY   refactoring
	private static final Map<String,String> USABLE_PROPARTY ;		// 6.4.1.1 (2016/01/16) usableProparty → USABLE_PROPARTY refactoring

	static {
		MUST_PROPARTY = new LinkedHashMap<>();
		MUST_PROPARTY.put( "host"	, "メールサーバー(必須)" );
		MUST_PROPARTY.put( "user"	, "メールを取得するログインユーザー(必須)" );
		MUST_PROPARTY.put( "passwd"	, "メールを取得するログインパスワード(必須)" );

		USABLE_PROPARTY = new LinkedHashMap<>();
		USABLE_PROPARTY.put( "protocol"		, "受信サーバーのプロトコル(imap,pop3)を指定(初期値:pop3)" );
		USABLE_PROPARTY.put( "port"			, "受信サーバーのポートを指定(初期値:-1)" );
		USABLE_PROPARTY.put( "useSSL"		, "SSL接続するかどうかを指定(初期値:false:しない)" );		// 6.3.8.0 (2015/09/11)
		USABLE_PROPARTY.put( "mailSaveDir"	, "受信メールをセーブするディレクトリ。" +
											CR + "指定がない場合は、標準出力へ出力する。" );
		USABLE_PROPARTY.put( "fileSaveDir"	, "添付ファイルをセーブするディレクトリ。" +
											CR + "指定がない場合は抜き出さない。" );
		USABLE_PROPARTY.put( "useMsgId"		, "添付ファイルをセーブするディレクトリに、" +
											CR + "MesssageIdフォルダを個別に割り当てるかどうか。" );
		USABLE_PROPARTY.put( "maxRowCount"	, "受信メールの最大取り込み件数(初期値:100)(0:[無制限])" );
		USABLE_PROPARTY.put( "match_Subject"	, "受信メールのSubjectを選択する条件" );
		USABLE_PROPARTY.put( "match_Body"	, "受信メールのBodyを選択する条件" );
		USABLE_PROPARTY.put( "match_From"	, "受信メールのFromを選択する条件" );
		USABLE_PROPARTY.put( "match_"		, "受信メールのヘッダー部のキーXXXXを選択する条件" );
		USABLE_PROPARTY.put( "delete"		, "検索後、メールをサーバーから削除するかどうかを、" +
											CR + "true/falseで指定(初期値:false)" );
		USABLE_PROPARTY.put( "help"			, "使用方法を出力して、終了します。" );
	}

	/**
	 * レシーバーを開始します。
	 *
	 * @og.rev 4.3.3.5 (2008/11/08) Argument オブジェクトへの引数を util → mail に訂正します。
	 * @og.rev 6.3.8.0 (2015/09/11) SSL接続するかどうかを指定するパラメータを追加します。
	 *
	 * @param   args 引数配列(可変長引数)
	 * @throws MessagingException なんらかのエラーが発生した場合。
	 */
	public void start( final String... args ) throws MessagingException {

		// パラメータの解析、取得
		LOGGER.fine( "パラメータの解析、取得" );
		argment = new Argument( "org.opengion.fukurou.fukurou.mail.MailReceiver" );		// 4.3.3.5 (2008/11/08)
		argment.setMustProparty( MUST_PROPARTY );
		argment.setUsableProparty( USABLE_PROPARTY );

		argment.setArgument( args );

		// help パラメータが true に指定された場合の処理。
		if( argment.getProparty( "help",false ) ) {
			System.out.println( argment.toString() );
			return;
		}

		// 処理に必要な各種パラメータを取得しておきます。
		LOGGER.fine( "処理に必要な各種パラメータを取得します。" );
		final MailRX recive = new MailRX();

		recive.setHost(			argment.getProparty( "host" ) ) ;
		recive.setUser(			argment.getProparty( "user" ) ) ;
		recive.setPasswd(		argment.getProparty( "passwd" ) ) ;
		recive.setProtocol(		argment.getProparty( "protocol"	,PROTOCOL ) ) ;
		recive.setPort(			argment.getProparty( "port"		,PORT ) ) ;
		recive.useSSL(			argment.getProparty( "useSSL"	,false ) ) ;			// 6.3.8.0 (2015/09/11)
		recive.setDelete(		argment.getProparty( "delete"	,DELETE_MESSAGE ) ) ;
		recive.setMaxRowCount(	argment.getProparty( "maxRowCount",MAX_ROW_COUNT ) ) ;

		// 指定の条件にマッチしたメッセージのみ抜き出す為の、SearchTerm オブジェクトの作成
		LOGGER.fine( "指定の条件にマッチしたメッセージのみ抜き出す条件を設定します。" );
		final HybsEntry[] matchs = argment.getEntrys( "match_" );
		for( int i=0; i<matchs.length; i++ ) {
			recive.addMatchTerm( matchs[i] ) ;
		}

		// リスナーを設定して、受信メールを一件ずつ処理します。
		LOGGER.fine( "リスナーを設定して、受信メールを一件ずつ処理します。" );
		final String mailSaveDir = argment.getProparty( "mailSaveDir" );
		final String fileSaveDir = argment.getProparty( "fileSaveDir" );
		final boolean useMsgId   = argment.getProparty( "useMsgId",false );

		final MailReceiveListener listener = new ReceiveListener( mailSaveDir,fileSaveDir,useMsgId ) ;
		recive.setMailReceiveListener( listener );

		recive.start();
	}

	/**
	 * メール受信プログラムで使用する MailReceiveListener の実装内部クラスです。
	 *
	 * @version  0.9.0  2000/11/13
	 * @author   Kazuhiko Hasegawa
	 * @since    JDK5.0,
	 */
	private static class ReceiveListener implements MailReceiveListener {
		private final String  mailSaveDir ;
		private final String  fileSaveDir ;
		private final boolean useMsgId ;
		private int   counter ;

		/**
		 * コンストラクター
		 *
		 * @param	mailSaveDir	メールをセーブする場合の保存フォルダ名
		 * @param	fileSaveDir	メールの添付ファイルをセーブする場合の保存フォルダ名
		 * @param	useMsgId	添付ファイルをセーブする場合に、メッセージIDを使用するかどうか
		 */
		public ReceiveListener( final String mailSaveDir,final String fileSaveDir,final boolean useMsgId ) {
			this.mailSaveDir = mailSaveDir;
			this.fileSaveDir = fileSaveDir;
			this.useMsgId    = useMsgId;
		}

		/**
		 * 受信処理を行います。
		 *
		 * @param   message MailMessageオブジェクト
		 * @return	結果(true:正常/false:異常)
		 */
		public boolean receive( final MailMessage message ) {
			final String msg = "[" + counter++ + "]" + message.getMessageID() + " 受信中" ;
			System.out.println( msg );

			// 6.4.1.1 (2016/01/16) PMD refactoring. Avoid if (x != y) ..; else ..;
			if( mailSaveDir == null ) {
				System.out.println( message.getSubject() );
				System.out.println( message.getContent() );
			}
			else {
//			if( mailSaveDir != null ) {
				message.saveMessage( mailSaveDir );
			}
//			else {
//				System.out.println( message.getSubject() );
//				System.out.println( message.getContent() );
//			}

			if( fileSaveDir != null ) {
				message.saveAttachFiles( fileSaveDir,useMsgId );
			}
			return true ;
		}
	}

	/**
	 * main メソッドです。
	 *
	 * @param	args	コマンド引数配列
	 */
	public static void main ( final String[] args ) {
		final MailReceiver receiver = new MailReceiver();
		try {
			LOGGER.info( "メール受信処理を開始します  ---------------------------------------------" );
			receiver.start( args );
			LOGGER.info( "正常に終了しました。" );
		}
		catch( Throwable th ) {
			final String errMsg = "メール受信中に例外が発生しました。 "
							+ CR + receiver.argment
							+ CR + th.getMessage() ;
//			LogWriter.log( errMsg );					// 6.3.8.0 (2015/09/11) 削除します。
			LOGGER.log( Level.SEVERE,errMsg, th );
//			throw new OgRuntimeException( errMsg,th );	// 6.3.8.0 (2015/09/11) 削除します。
		}
	}
}
